searchNodes=[{"ref":"Unleash.html","title":"Unleash","type":"module","doc":"If you have no plans on extending the client, then Unleash will be the main usage point of the library. Upon starting your app, the client is registered with the unleash server, and two GenServers are started, one to fetch and poll for feature flags from the server, and one to send metrics. Configuring :disable_client to true disables both servers as well as registration, while configuring :disable_metrics to true disables only the metrics GenServer."},{"ref":"Unleash.html#enabled?/2","title":"Unleash.enabled?/2","type":"function","doc":"Checks if the given feature is enabled. Checks as though an empty context was passed in. Examples iex&gt; Unleash.enabled?(:my_feature, false) false iex&gt; Unleash.enabled?(:my_feature, true) true"},{"ref":"Unleash.html#enabled?/3","title":"Unleash.enabled?/3","type":"function","doc":"Checks if the given feature is enabled. If :disable_client is true, simply returns the given default. If :disable_metrics is true, nothing is logged about the given toggle. Examples iex&gt; Unleash.enabled?(:my_feature) false iex&gt; Unleash.enabled?(:my_feature, context) false iex&gt; Unleash.enabled?(:my_feature, context, true) false"},{"ref":"Unleash.html#get_variant/3","title":"Unleash.get_variant/3","type":"function","doc":"Returns a variant for the given name. If :disable_client is true, returns the fallback. A variant allows for more complicated toggling than a simple true/false, instead returning one of the configured variants depending on whether or not there are any overrides for a given context value as well as factoring in the weights for the various weight options. Examples iex&gt; Unleash.get_variant(:test) %{enabled: true, name: &quot;test&quot;, payload: %{...}} iex&gt; Unleash.get_variant(:test) %{enabled: false, name: &quot;disabled&quot;}"},{"ref":"Unleash.html#is_enabled?/2","title":"Unleash.is_enabled?/2","type":"function","doc":"Aliased to enabled?/2"},{"ref":"Unleash.html#is_enabled?/3","title":"Unleash.is_enabled?/3","type":"function","doc":"Aliased to enabled?/3"},{"ref":"Unleash.html#t:context/0","title":"Unleash.context/0","type":"type","doc":"The context needed for a few activation strategies. Check their documentation for the required key. :user_id is the ID of the user interacting with your system, can be any String.t() session_id is the ID of the current session in your system, can be any String.t() remote_address is the address of the user interacting with your system, can be any String.t()"},{"ref":"Unleash.Plug.html","title":"Unleash.Plug","type":"module","doc":"An extra fancy Plug and utility functions to help when developing Plug or Phoenix-based applications. It automatically puts together a Unleash.context/0 under the Plug.Conn&#39;s Plug.assigns/0. To use, call plug Unleash.Plug in your plug pipeline. It depends on the session, and requires being after :fetch_session to work. It accepts the following options: :user_id: The key under which the user&#39;s ID is found in the session. :session_id: The key under wwhich the session ID is found in the session. After which, enabled?/3 is usable. If you are also using PhoenixGon in your application, you can call put_feature/3 to put a specific feature flag into the gon object for using on the client side."},{"ref":"Unleash.Plug.html#enabled?/3","title":"Unleash.Plug.enabled?/3","type":"function","doc":"Given a t:Plug.Conn/0, a feature, and (optionally) a boolean, return whether or not a feature is enabled. This requires this plug to be a part of the plug pipeline, as it will construct an t:Unleash.context()/0 out of the session. Examples iex&gt; Unleash.Plug.enabled?(conn, :test) false iex&gt; Unleash.Plug.enabled?(conn, :test, true) true"},{"ref":"Unleash.Plug.html#put_feature/3","title":"Unleash.Plug.put_feature/3","type":"function","doc":"If you are using PhoenixGon, you can call this to put a feature in the gon object to be used on the client side. It will be available under window.Gon.getAssets(&#39;features&#39;). It listens to the options that are configured by PhoenixGon.Pipeline. Examples iex&gt; Unleash.Plug.put_feature(conn, :test) %Plug.Conn{} iex&gt; Unleash.Plug.enabled?(conn, :test, true) %Plug.Conn{}"},{"ref":"Unleash.Strategies.html","title":"Unleash.Strategies","type":"behaviour","doc":"Used to get all available strategies in the client. You can add your strategies to the client by extending this module: defmodule MyApp.Strategies do @behaviour Unleash.Strategies def strategies, do: Unleash.Strategies.strategies() ++ [] end and then setting it in your configuration: config :unleash, Unleash, strategies: MyApp.Strategies"},{"ref":"Unleash.Strategies.html#strategies/0","title":"Unleash.Strategies.strategies/0","type":"function","doc":"Returns all the strategies that are supported by this client. They can be viewed under Strategy. For completeness, the list is: userWithId: Unleash.Strategy.ActiveForUsersWithId applicationHostname: Unleash.Strategy.ApplicationHostname default: Unleash.Strategy.Default gradualRolloutRandom: Unleash.Strategy.GradualRolloutRandom gradualRolloutSessionId: Unleash.Strategy.GradualRolloutSessionId gradualRolloutUserId: Unleash.Strategy.GradualRolloutUserId remoteAddress: Unleash.Strategy.RemoteAddress"},{"ref":"Unleash.Strategies.html#c:strategies/0","title":"Unleash.Strategies.strategies/0","type":"callback","doc":"Should return a list of all the avilable strategies in the format {&quot;name&quot;, Module}. The name must match the name of the strategy in the Unleash server, and the module must implement the Unleash.Strategy behaviour."},{"ref":"Unleash.Strategy.html","title":"Unleash.Strategy","type":"behaviour","doc":"Used to extend the client and create custom strategies. To do so, use this module within your custom strategy and implmenent enabled?/2. Provide a name that is human-readable, as it is logged. defmodule MyApp.CustomStrategy use Unleash.Strategy, name: &quot;CustomStrategy&quot; def enabled?(_params, _context), do: true end"},{"ref":"Unleash.Strategy.html#c:enabled?/2","title":"Unleash.Strategy.enabled?/2","type":"callback","doc":"You can implmenet this callback a couple of ways, returning a bare boolean() or a {boolean, map()}. The latter is preferred, as it generates a :debug level log entry detailing the name of the strategy, the result, and the contents of map(), in an effort to help understand why the result was what it was. Arguments parameters - A map of paramters returned from the Unleash server. This can be whatever you like, such as a configured list of userIds. context - The context passed into Unleash.enabled?/3. Examples @behaviour Unleash.Strategy def enabled?(params, context), do: {false, params} def enabled(params, %{}), do: false"},{"ref":"Unleash.Strategy.html#log_result/2","title":"Unleash.Strategy.log_result/2","type":"function","doc":""},{"ref":"Unleash.Strategy.ActiveForUsersWithId.html","title":"Unleash.Strategy.ActiveForUsersWithId","type":"module","doc":"Requires :user_id in Unleash.context/0 Based on the userWithId strategy."},{"ref":"Unleash.Strategy.ApplicationHostname.html","title":"Unleash.Strategy.ApplicationHostname","type":"module","doc":"Does not require anything in Unleash.context/0 Based on the applicationHostname strategy."},{"ref":"Unleash.Strategy.ApplicationHostname.html#enabled?/2","title":"Unleash.Strategy.ApplicationHostname.enabled?/2","type":"function","doc":"You can implmenet this callback a couple of ways, returning a bare boolean() or a {boolean, map()}. The latter is preferred, as it generates a :debug level log entry detailing the name of the strategy, the result, and the contents of map(), in an effort to help understand why the result was what it was. Arguments parameters - A map of paramters returned from the Unleash server. This can be whatever you like, such as a configured list of userIds. context - The context passed into Unleash.enabled?/3. Examples @behaviour Unleash.Strategy def enabled?(params, context), do: {false, params} def enabled(params, %{}), do: false Callback implementation for Unleash.Strategy.enabled?/2."},{"ref":"Unleash.Strategy.Constraint.html","title":"Unleash.Strategy.Constraint","type":"module","doc":"Module that is used to verify constraints are met. These constraints allow for very complex and specifc strategies to be enacted by allowing users to specify context values to include or exclude."},{"ref":"Unleash.Strategy.Constraint.html#verify_all/2","title":"Unleash.Strategy.Constraint.verify_all/2","type":"function","doc":""},{"ref":"Unleash.Strategy.Default.html","title":"Unleash.Strategy.Default","type":"module","doc":"Does not require anything in Unleash.context/0 Based on the default strategy."},{"ref":"Unleash.Strategy.Default.html#enabled?/2","title":"Unleash.Strategy.Default.enabled?/2","type":"function","doc":"You can implmenet this callback a couple of ways, returning a bare boolean() or a {boolean, map()}. The latter is preferred, as it generates a :debug level log entry detailing the name of the strategy, the result, and the contents of map(), in an effort to help understand why the result was what it was. Arguments parameters - A map of paramters returned from the Unleash server. This can be whatever you like, such as a configured list of userIds. context - The context passed into Unleash.enabled?/3. Examples @behaviour Unleash.Strategy def enabled?(params, context), do: {false, params} def enabled(params, %{}), do: false Callback implementation for Unleash.Strategy.enabled?/2."},{"ref":"Unleash.Strategy.FlexibleRollout.html","title":"Unleash.Strategy.FlexibleRollout","type":"module","doc":"Can depend on :user_id or :session_id in Unleash.context/0 Based on the flexibleRollout strategy."},{"ref":"Unleash.Strategy.FlexibleRollout.html#enabled?/2","title":"Unleash.Strategy.FlexibleRollout.enabled?/2","type":"function","doc":"You can implmenet this callback a couple of ways, returning a bare boolean() or a {boolean, map()}. The latter is preferred, as it generates a :debug level log entry detailing the name of the strategy, the result, and the contents of map(), in an effort to help understand why the result was what it was. Arguments parameters - A map of paramters returned from the Unleash server. This can be whatever you like, such as a configured list of userIds. context - The context passed into Unleash.enabled?/3. Examples @behaviour Unleash.Strategy def enabled?(params, context), do: {false, params} def enabled(params, %{}), do: false Callback implementation for Unleash.Strategy.enabled?/2."},{"ref":"Unleash.Strategy.GradualRolloutRandom.html","title":"Unleash.Strategy.GradualRolloutRandom","type":"module","doc":"Does not require anything in Unleash.context/0 Based on the gradualRollourRandom strategy."},{"ref":"Unleash.Strategy.GradualRolloutSessionId.html","title":"Unleash.Strategy.GradualRolloutSessionId","type":"module","doc":"Requires :session_id in Unleash.context/0 Based on the gradualRolloutSessionId strategy."},{"ref":"Unleash.Strategy.GradualRolloutSessionId.html#enabled?/2","title":"Unleash.Strategy.GradualRolloutSessionId.enabled?/2","type":"function","doc":"You can implmenet this callback a couple of ways, returning a bare boolean() or a {boolean, map()}. The latter is preferred, as it generates a :debug level log entry detailing the name of the strategy, the result, and the contents of map(), in an effort to help understand why the result was what it was. Arguments parameters - A map of paramters returned from the Unleash server. This can be whatever you like, such as a configured list of userIds. context - The context passed into Unleash.enabled?/3. Examples @behaviour Unleash.Strategy def enabled?(params, context), do: {false, params} def enabled(params, %{}), do: false Callback implementation for Unleash.Strategy.enabled?/2."},{"ref":"Unleash.Strategy.GradualRolloutUserId.html","title":"Unleash.Strategy.GradualRolloutUserId","type":"module","doc":"Requires :user_id in Unleash.context/0 Based on the gradualRolloutUserId strategy."},{"ref":"Unleash.Strategy.GradualRolloutUserId.html#enabled?/2","title":"Unleash.Strategy.GradualRolloutUserId.enabled?/2","type":"function","doc":"You can implmenet this callback a couple of ways, returning a bare boolean() or a {boolean, map()}. The latter is preferred, as it generates a :debug level log entry detailing the name of the strategy, the result, and the contents of map(), in an effort to help understand why the result was what it was. Arguments parameters - A map of paramters returned from the Unleash server. This can be whatever you like, such as a configured list of userIds. context - The context passed into Unleash.enabled?/3. Examples @behaviour Unleash.Strategy def enabled?(params, context), do: {false, params} def enabled(params, %{}), do: false Callback implementation for Unleash.Strategy.enabled?/2."},{"ref":"Unleash.Strategy.RemoteAddress.html","title":"Unleash.Strategy.RemoteAddress","type":"module","doc":"Requires :remote_address in Unleash.context/0 Based on the remoteAddress strategy."},{"ref":"Unleash.Strategy.Utils.html","title":"Unleash.Strategy.Utils","type":"module","doc":"Utilities that might help you create your own strategies. Automatically aliased when useing Unleash.Strategy"},{"ref":"Unleash.Strategy.Utils.html#in_list?/3","title":"Unleash.Strategy.Utils.in_list?/3","type":"function","doc":"Given a comma-separated list and a member, check to see if the member is in the list. An optional transformation function can be passed in to apply to the items in the list. Examples iex&gt; in_list?(&quot;a,B,c,D&quot;, &quot;b&quot;, &amp;String.downcase/1) true iex&gt; in_list?(&quot;a,B,c,D&quot;, &quot;b&quot;) false"},{"ref":"Unleash.Strategy.Utils.html#normalize/3","title":"Unleash.Strategy.Utils.normalize/3","type":"function","doc":"Given an ID and group ID, normalize them using a Murmur hash. Used in all strategies that provide &quot;stickiness&quot;. See the gradualRolloutUserId strategy."},{"ref":"Unleash.Strategy.Utils.html#parse_int/1","title":"Unleash.Strategy.Utils.parse_int/1","type":"function","doc":"Parse a string to a non-negative integer, returning only the number or 0 if it isn&#39;t just a number. Examples iex&gt; parse_int(&quot;5&quot;) 5 iex&gt; parse_int(&quot;5ab23a&quot;) 0 iex&gt; parse_int(5) 5"},{"ref":"readme.html","title":"Unleash","type":"extras","doc":"Unleash Unleash is a client for the Unleash Toggle Service. The primary use is Unleash.enabled?/2 or Unleash.enabled?/3 to check whether or not the given feature flag is enabled. iex&gt; Unleash.enabled?(:my_feature) false iex&gt; Unleash.enabled?(:my_feature, true) true iex&gt; Unleash.enabled?(:my_feature, context) true iex&gt; Unleash.enabled?(:my_feature, context, false) true"},{"ref":"readme.html#installation","title":"Unleash - Installation","type":"extras","doc":"If available in Hex, the package can be installed by adding unleash_ex to your list of dependencies in mix.exs: def deps do [ {:unleash, &quot;~&gt; 1.0&quot;} ] end"},{"ref":"readme.html#configuration","title":"Unleash - Configuration","type":"extras","doc":"There are many configuration options available, and they are listed below with their defaults. These go into the relevant config/*.exs file. config :unleash, Unleash, url: &quot;&quot;, # The URL of the Unleash server to connect to, should include up to http://base.url/api appname: &quot;&quot;, # The app name, used for registration instance_id: &quot;&quot;, # The instance ID, used for metrics tracking metrics_period: 10 * 60 * 1000, # Send metrics every 10 minutes, in milliseconds features_period: 15 * 1000, # Poll for new flags every 15 seconds, in milliseconds strategies: Unleash.Strategies, # Which module to request for toggle strategies backup_file: nil, # Backup file in the event that contacting the server fails custom_http_headers: [], # A keyword list of custom headers to send to the server disable_client: false, # Whether or not to enable the client disable_metrics: false, # Whether or not to send metrics, retries: -1 # How many times to retry on failure, -1 disables limit app_env: :dev # Which environment we&#39;re in :custom_http_headers should follow the format prescribed by Mojito.headers/0 :strategies should be a module that implements Unleash.Strategies.strategies/0. See Extensibility for more information."},{"ref":"readme.html#extensibility","title":"Unleash - Extensibility","type":"extras","doc":"If you need to create your own strategies, you can extend the Unleash client by implementing the callbacks in both Unleash.Strategy and Unleash.Strategies as well as passing your new Strategies module in as configuration: Create your new strategy. See Unleash.Strategy for details on the correct API and Unleash.Strategy.Utils for helpful utilities. defmodule MyApp.Strategy.Environment do use Unleash.Strategy def enabled?(%{&quot;environments&quot; =&gt; environments}, _context) do with {:ok, environment} &lt;- MyApp.Config.get_environment(), environment = List.to_string(environment) do {Utils.in_list?(environments, environment, &amp;String.downcase/1), %{environment: environment, environments: environments}} end end end Create a new strategies module. See Unleash.Strategies for details on the correct API. defmodule MyApp.Strategies do @behaviour Unleash.Strategies def strategies do [{&quot;environment&quot;, MyApp.Strategy.Environment}] ++ Unleash.Strategies.strateges() end end Configure your application to use your new strategies list. config :unleash, Unleash, strategies: MyApp.Strategies"}]